projectal.dynamic_enums.priority_levels API documentation

# projectal.dynamic_enums.priority_levels

View Source

    1from projectal.dynamic_enum import DynamicEnum
    2
    3
    4class PriorityLevels(DynamicEnum):
    5    _name = "GanttPriorityEnum"

class PriorityLevels(projectal.dynamic_enum.DynamicEnum): View Source

    5class PriorityLevels(DynamicEnum):
    6    _name = "GanttPriorityEnum"

##### Inherited Members

projectal.dynamic_enum.DynamicEnum
  get
  set